summaryrefslogtreecommitdiff
path: root/driver
diff options
context:
space:
mode:
Diffstat (limited to 'driver')
-rw-r--r--driver/tcpm/anx74xx.c6
-rw-r--r--driver/tcpm/it83xx.c2
-rw-r--r--driver/tcpm/ps8xxx.c6
-rw-r--r--driver/tcpm/tcpci.c6
-rw-r--r--driver/tcpm/tcpci.h2
-rw-r--r--driver/tcpm/tcpm.h4
6 files changed, 13 insertions, 13 deletions
diff --git a/driver/tcpm/anx74xx.c b/driver/tcpm/anx74xx.c
index 8973a34213..bf75e21e07 100644
--- a/driver/tcpm/anx74xx.c
+++ b/driver/tcpm/anx74xx.c
@@ -1099,17 +1099,17 @@ static int anx74xx_tcpm_init(int port)
return EC_SUCCESS;
}
-static int anx74xx_get_chip_info(int port, int renew,
+static int anx74xx_get_chip_info(int port, int live,
struct ec_response_pd_chip_info_v1 **chip_info)
{
- int rv = tcpci_get_chip_info(port, renew, chip_info);
+ int rv = tcpci_get_chip_info(port, live, chip_info);
int val;
if (rv)
return rv;
if ((*chip_info)->fw_version_number == 0 ||
- (*chip_info)->fw_version_number == -1 || renew) {
+ (*chip_info)->fw_version_number == -1 || live) {
rv = tcpc_read(port, ANX74XX_REG_FW_VERSION, &val);
if (rv)
diff --git a/driver/tcpm/it83xx.c b/driver/tcpm/it83xx.c
index da0cdf35e1..ac0383f719 100644
--- a/driver/tcpm/it83xx.c
+++ b/driver/tcpm/it83xx.c
@@ -577,7 +577,7 @@ static int it83xx_tcpm_transmit(int port,
return EC_SUCCESS;
}
-static int it83xx_tcpm_get_chip_info(int port, int renew,
+static int it83xx_tcpm_get_chip_info(int port, int live,
struct ec_response_pd_chip_info_v1 **chip_info)
{
static struct ec_response_pd_chip_info_v1 i;
diff --git a/driver/tcpm/ps8xxx.c b/driver/tcpm/ps8xxx.c
index 6e49e8429d..590e642ab0 100644
--- a/driver/tcpm/ps8xxx.c
+++ b/driver/tcpm/ps8xxx.c
@@ -131,17 +131,17 @@ static int ps8xxx_tcpm_release(int port)
return tcpci_tcpm_release(port);
}
-static int ps8xxx_get_chip_info(int port, int renew,
+static int ps8xxx_get_chip_info(int port, int live,
struct ec_response_pd_chip_info_v1 **chip_info)
{
int val;
- int rv = tcpci_get_chip_info(port, renew, chip_info);
+ int rv = tcpci_get_chip_info(port, live, chip_info);
if (rv)
return rv;
if ((*chip_info)->fw_version_number == 0 ||
- (*chip_info)->fw_version_number == -1 || renew) {
+ (*chip_info)->fw_version_number == -1 || live) {
rv = tcpc_read(port, FW_VER_REG, &val);
if (rv)
diff --git a/driver/tcpm/tcpci.h b/driver/tcpm/tcpci.h
index 674d227dca..285cba1f57 100644
--- a/driver/tcpm/tcpci.h
+++ b/driver/tcpm/tcpci.h
@@ -161,7 +161,7 @@ int tcpci_tcpm_mux_init(int i2c_addr);
int tcpci_tcpm_mux_set(int i2c_addr, mux_state_t mux_state);
int tcpci_tcpm_mux_get(int i2c_addr, mux_state_t *mux_state);
int tcpci_tcpm_mux_enter_low_power(int port);
-int tcpci_get_chip_info(int port, int renew,
+int tcpci_get_chip_info(int port, int live,
struct ec_response_pd_chip_info_v1 **chip_info);
#ifdef CONFIG_USBC_PPC
int tcpci_tcpm_set_snk_ctrl(int port, int enable);
diff --git a/driver/tcpm/tcpm.h b/driver/tcpm/tcpm.h
index fb67eb315b..9d03f52500 100644
--- a/driver/tcpm/tcpm.h
+++ b/driver/tcpm/tcpm.h
@@ -238,11 +238,11 @@ static inline int tcpc_i2c_write__7bf(const int port, const uint16_t addr__7bf,
}
#endif
-static inline int tcpm_get_chip_info(int port, int renew,
+static inline int tcpm_get_chip_info(int port, int live,
struct ec_response_pd_chip_info_v1 **info)
{
if (tcpc_config[port].drv->get_chip_info)
- return tcpc_config[port].drv->get_chip_info(port, renew, info);
+ return tcpc_config[port].drv->get_chip_info(port, live, info);
return EC_ERROR_UNIMPLEMENTED;
}
diff --git a/driver/tcpm/tcpci.c b/driver/tcpm/tcpci.c
index 6765ce7bdc..129adf3da9 100644
--- a/driver/tcpm/tcpci.c
+++ b/driver/tcpm/tcpci.c
@@ -666,7 +666,7 @@ void tcpci_tcpc_alert(int port)
* Once it's called, the chip info will be stored in cache, which can be
* accessed by tcpm_get_chip_info without worrying about chip states.
*/
-int tcpci_get_chip_info(int port, int renew,
+int tcpci_get_chip_info(int port, int live,
struct ec_response_pd_chip_info_v1 **chip_info)
{
static struct ec_response_pd_chip_info_v1
@@ -685,8 +685,8 @@ int tcpci_get_chip_info(int port, int renew,
if (chip_info)
*chip_info = i;
- /* If already populated and renewal is not asked, return cache value */
- if (i->vendor_id && !renew)
+ /* If already cached && live data is not asked, return cached value */
+ if (i->vendor_id && !live)
return EC_SUCCESS;
error = tcpc_read16(port, TCPC_REG_VENDOR_ID, &val);